abacusai.api_class.document_retriever — AbacusAI documentation

# `abacusai.api_class.document_retriever`

## Module Contents

### Classes

`VectorStoreConfig` | Configs for vector store indexing.
`DocumentRetrieverConfig` | Configs for document retriever.

class abacusai.api_class.document_retriever.VectorStoreConfig

  Bases: `abacusai.api_class.abstract.ApiClass`

  Configs for vector store indexing.

  Parameters:

    - chunk_size (int) – The size of text chunks in the vector store.

    - chunk_overlap_fraction (float) – The fraction of overlap between chunks.

    - text_encoder (VectorStoreTextEncoder) – Encoder used to index texts from the documents.

  chunk_size: int
  chunk_overlap_fraction: float
  text_encoder: abacusai.api_class.enums.VectorStoreTextEncoder

class abacusai.api_class.document_retriever.DocumentRetrieverConfig

  Bases: `VectorStoreConfig`

  Configs for document retriever.